@@ -4,25 +4,29 @@ Top-level package for python lung morphometrics.
 
 __author__ = """Sylvia N. Michki"""
 __email__ = 'sylvia.michki@gmail.com'
-__version__ = '0.2.0'
+__version__ = '0.4.0'
 
 
 from ._do_mli import (
 	do_mli
 )
-'''
+
 from ._he_lung_injury_classification import(
 	make_kmeans_model_from_images,
-	cluster_image
+	do_kmeans_cluster_image,
+	train_feature_based_random_forest_model,
+	apply_feature_based_random_forest_model
 )
-'''
 from ._colocalization_analysis import(
 	do_colocalization_analysis
 )
 
 __all__ = [
     "do_mli",
-    #"make_kmeans_model_from_images",
-    #"cluster_image",
-    "do_colocalization_analysis"
+    "make_kmeans_model_from_images",
+    "do_kmeans_cluster_image",
+    "do_colocalization_analysis",
+    "train_feature_based_random_forest_model",
+    "apply_feature_based_random_forest_model"
+    "models"
 ]
\ No newline at end of file
